==> drd-8.x-3.5.tar.gz: drd/src/Plugin/Update/Process/Base.php <==
<?php

namespace Drupal\drd\Plugin\Update\Process;

use Drupal\Core\Form\FormStateInterface;
use Drupal\drd\DomainLocalCopy;
use Drupal\drd\Plugin\Update\Base as UpdateBase;
use Drupal\drd\Update\PluginProcessInterface;

/**
 * Abstract DRD Update plugin to implement general process functionality.
 */
abstract class Base extends UpdateBase implements PluginProcessInterface {

  protected $succeeded = FALSE;
  private $originalSites = FALSE;

  /**
   * @inheritDoc
   */
  final public function hasSucceeded() {
    return $this->succeeded;
  }

  protected function requiresDatabase() {
    return FALSE;
  }

  /**
   * @inheritDoc
   */
  public function defaultConfiguration() {
    return [
      'pulldb' => FALSE,
    ] + parent::defaultConfiguration();
  }

  /**
   * @inheritDoc
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $element = parent::buildConfigurationForm($form, $form_state);

    $element['pulldb'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Pull database(s) from production server'),
      '#default_value' => $this->requiresDatabase() ? TRUE : $this->configuration['pulldb'],
      '#disabled' => $this->requiresDatabase(),
    ];

    return $element;
  }

  /**
   * @inheritDoc
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
    $this->configuration['pulldb'] = !empty($this->getFormValue($form_state, 'pulldb'));
  }

  /**
   * @inheritDoc
   */
  public function process($storage) {
    if ($this->configuration['pulldb']) {
      $sites_file = $storage->getDrupalDirectory() . DIRECTORY_SEPARATOR . 'sites/sites.php';
      if (file_exists($sites_file)) {
        $this->originalSites = file_get_contents($sites_file);
        unlink($sites_file);
      }
      foreach ($storage->getCore()->getDomains() as $domain) {
        /** @var DomainLocalCopy $service */
        $service = \Drupal::service('drd_domain.local_copy');
        $result = $service
          ->setDrupalDirectory($storage->getDrupalDirectory())
          ->setWorkingDirectory($storage->getWorkingDirectory())
          ->setDomain($domain)
          ->setup();
        $storage->log($service->getLog());
        if (!$result) {
          throw new \Exception('Can not pull database.');
        }
      }
    }
    return $this;
  }

  /**
   * @inheritDoc
   */
  public function cleanup($storage) {
    parent::cleanup($storage);
    $sites_file = $storage->getDrupalDirectory() . DIRECTORY_SEPARATOR . 'sites/sites.php';
    if ($this->originalSites) {
      file_put_contents($sites_file, $this->originalSites);
    }
    elseif (file_exists($sites_file)) {
      unlink($sites_file);
    }
    return $this;
  }


}

==> drd-8.x-3.7.tar.gz: drd/src/Plugin/Update/Process/Base.php <==
<?php

namespace Drupal\drd\Plugin\Update\Process;

use Drupal\Core\Form\FormStateInterface;
use Drupal\drd\Plugin\Update\Base as UpdateBase;
use Drupal\drd\Update\PluginProcessInterface;

/**
 * Abstract DRD Update plugin to implement general process functionality.
 */
abstract class Base extends UpdateBase implements PluginProcessInterface {

  protected $succeeded = FALSE;
  private $originalSites = FALSE;

  /**
   * @inheritDoc
   */
  final public function hasSucceeded() {
    return $this->succeeded;
  }

  protected function requiresDatabase() {
    return FALSE;
  }

  /**
   * @inheritDoc
   */
  public function defaultConfiguration() {
    return [
      'pulldb' => FALSE,
    ] + parent::defaultConfiguration();
  }

  /**
   * @inheritDoc
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $element = parent::buildConfigurationForm($form, $form_state);

    $element['pulldb'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Pull database(s) from production server'),
      '#default_value' => $this->requiresDatabase() ? TRUE : $this->configuration['pulldb'],
      '#disabled' => $this->requiresDatabase(),
    ];

    return $element;
  }

  /**
   * @inheritDoc
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
    $this->configuration['pulldb'] = !empty($this->getFormValue($form_state, 'pulldb'));
  }

  /**
   * @inheritDoc
   */
  public function process($storage) {
    if ($this->configuration['pulldb']) {
      $sites_file = $storage->getDrupalDirectory() . DIRECTORY_SEPARATOR . 'sites/sites.php';
      if (file_exists($sites_file)) {
        $this->originalSites = file_get_contents($sites_file);
        unlink($sites_file);
      }
      foreach ($storage->getCore()->getDomains() as $domain) {
        /** @var \Drupal\drd\DomainLocalCopy $service */
        $service = \Drupal::service('drd_domain.local_copy');
        $result = $service
          ->setDrupalDirectory($storage->getDrupalDirectory())
          ->setWorkingDirectory($storage->getWorkingDirectory())
          ->setDomain($domain)
          ->setup();
        $storage->log($service->getLog());
        if (!$result) {
          throw new \Exception('Can not pull database.');
        }
      }
    }
    return $this;
  }

  /**
   * @inheritDoc
   */
  public function cleanup($storage) {
    parent::cleanup($storage);
    $sites_file = $storage->getDrupalDirectory() . DIRECTORY_SEPARATOR . 'sites/sites.php';
    if ($this->originalSites) {
      file_put_contents($sites_file, $this->originalSites);
    }
    elseif (file_exists($sites_file)) {
      unlink($sites_file);
    }
    return $this;
  }


}
